@@ -1,4 +1,7 @@
+package PerlIO::dir;
+use strict;
 require PerlIO::Util;
+1;
 __END__
 
 =encoding utf-8
@@ -22,7 +25,7 @@ C<PerlIO::dir> provides an interface to read directories.
 
 There is an important difference between C<:dir> and Perl's C<readdir()>. This
 layer B<appends a newline code>, C<\n>, to the end of the name, because
-C<readline()> requires input separators. Call C<chomp()> if necesary.
+C<readline()> requires input separators. Call C<chomp()> if necessary.
 
 You can use C<seek($dir, 0, 0)> only for C<rewinddir()>. 
 
